@@ -1,7 +1,7 @@
 use strict;
 package HTTP::BrowserDetect;
 BEGIN {
-  $HTTP::BrowserDetect::VERSION = '1.28';
+  $HTTP::BrowserDetect::VERSION = '1.29';
 }
 
 use vars qw(@ISA @EXPORT @EXPORT_OK @ALL_TESTS);
@@ -12,7 +12,7 @@ require Exporter;
 @EXPORT_OK = qw();
 
 # Operating Systems
-push @ALL_TESTS, qw(
+my @os = qw(
     win16   win3x       win31
     win95   win98       winnt
     windows win32       win2k
@@ -30,9 +30,11 @@ push @ALL_TESTS, qw(
     freebsd bsd         vms
     x11     amiga       android
     win7    ps3gameos   pspgameos
-    wince
+    wince   ios
 );
 
+push @ALL_TESTS, @os;
+
 # Devices
 push @ALL_TESTS, qw(
     palm    audrey      iopener
@@ -612,6 +614,7 @@ sub _test {
         = (    ( $tests->{MAC} )
             && ( index( $ua, "ppc" ) != -1 || index( $ua, "powerpc" ) != -1 )
         );
+    $tests->{IOS} = $tests->{IPAD} || $tests->{IPOD} || $tests->{IPHONE};
 
     # Others
 
@@ -762,6 +765,7 @@ sub os_string {
         $os_string = 'Linux'    if $self->linux;
         $os_string = 'Playstation 3 GameOS' if $self->ps3gameos;
         $os_string = 'Playstation Portable GameOS' if $self->pspgameos;
+        $os_string = 'iOS' if $self->iphone || $self->ipod || $self->ipad;
     }
     return $os_string;
 }
@@ -1114,7 +1118,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 1.28
+version 1.29
 
 =head1 SYNOPSIS
 
@@ -1325,7 +1329,7 @@ winnt, which is a type of win32)
 
 =head2 mac()
 
-mac68k macppc macosx
+mac68k macppc macosx ios
 
 =head2 os2()
 
@@ -1352,7 +1356,7 @@ distinguish between Win95 and WinNT.
 Returns one of the following strings, or undef. This method exists solely for
 compatibility with the L<HTTP::Headers::UserAgent> module.
 
-  Win95, Win98, WinNT, Win2K, WinXP, Win2k3, WinVista, Win7, Mac, Mac OS X,
+  Win95, Win98, WinNT, Win2K, WinXP, Win2k3, WinVista, Win7, Mac, Mac OS X, iOS,
   Win3x, OS2, Unix, Linux, Playstation 3 GameOS, Playstation Portable GameOS
 
 =head1 Detecting Browser Vendor
